"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.serializeArguments = void 0;
const askar_shared_1 = require("@openwallet-foundation/askar-shared");
const serialize = (arg) => {
    switch (typeof arg) {
        case 'undefined':
            return arg;
        case 'string':
            return arg;
        case 'boolean':
            return Number(arg);
        case 'number':
            return arg;
        case 'function':
            return arg;
        case 'object':
            if (arg instanceof Date) {
                return arg.valueOf();
            }
            if (arg instanceof Uint8Array) {
                return arg.buffer;
            }
            if (arg instanceof askar_shared_1.Jwk) {
                return arg.toUint8Array().buffer;
            }
            if (arg instanceof askar_shared_1.Key) {
                return arg.handle.handle;
            }
            if (arg instanceof askar_shared_1.StoreHandle ||
                arg instanceof askar_shared_1.SessionHandle ||
                arg instanceof askar_shared_1.ScanHandle ||
                arg instanceof askar_shared_1.ArcHandle) {
                return arg.handle;
            }
            return JSON.stringify(arg);
        default:
            // eslint-disable-next-line @typescript-eslint/restrict-template-expressions
            throw new Error(`Could not serialize value ${arg}`);
    }
};
const serializeArguments = (args) => {
    const retVal = {};
    for (const [key, value] of Object.entries(args)) {
        retVal[key] = serialize(value);
    }
    return retVal;
};
exports.serializeArguments = serializeArguments;
//# sourceMappingURL=serialize.js.map